@@ -1,5 +1,3 @@
-import sys
-
 from _pytest import main as pytest_main
 from find_dependencies.dependency_finder import DependencyFinder, run_tests
 
@@ -12,6 +10,12 @@ def pytest_addoption(parser):
         dest="find_dependencies",
         help="""Find dependencies between tests""",
     )
+    group.addoption(
+        "--reversed-first",
+        action="store_true",
+        dest="reversed_first",
+        help="""Run the test in reverse direction first""",
+    )
     group.addoption(
         "--find-dependencies-internal",
         action="store_true",
@@ -20,17 +24,16 @@ def pytest_addoption(parser):
     )
 
 
-def pytest_cmdline_preparse(args):
-    if "--find-dependencies" in args and "pytest_randomly" in sys.modules:
-        args[:] = ["--randomly-dont-reorganize"] + args
-
-
 def pytest_runtestloop(session):
     if session.config.getoption("find_dependencies_internal"):
         return run_tests(session)
     if not session.config.getoption("find_dependencies"):
         return pytest_main.pytest_runtestloop(session)
 
+    if len(session.items) == 1:
+        print("Only one test collected: ignoring option --find-dependencies")
+        return pytest_main.pytest_runtestloop(session)
+
     if (session.testsfailed and
             not session.config.option.continue_on_collection_errors):
         raise session.Interrupted(
